@@ -25,14 +25,19 @@ class ListProductsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Workorder', '2021-06-10', 'ListProducts')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Language(self): # String
+		return self.get_query_params().get('Language')
 
-	def get_Name(self):
+	def set_Language(self, Language):  # String
+		self.add_query_param('Language', Language)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
