@@ -25,26 +25,30 @@ class ReplyTicketRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Workorder', '2021-06-10', 'ReplyTicket')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Content(self):
+	def get_Content(self): # String
 		return self.get_body_params().get('Content')
 
-	def set_Content(self,Content):
+	def set_Content(self, Content):  # String
 		self.add_body_params('Content', Content)
+	def get_FileNameList(self): # Array
+		return self.get_query_params().get('FileNameList')
 
-	def get_Encrypt(self):
+	def set_FileNameList(self, FileNameList):  # Array
+		for index1, value1 in enumerate(FileNameList):
+			self.add_query_param('FileNameList.' + str(index1 + 1), value1)
+	def get_Encrypt(self): # Boolean
 		return self.get_body_params().get('Encrypt')
 
-	def set_Encrypt(self,Encrypt):
+	def set_Encrypt(self, Encrypt):  # Boolean
 		self.add_body_params('Encrypt', Encrypt)
-
-	def get_TicketId(self):
+	def get_TicketId(self): # String
 		return self.get_body_params().get('TicketId')
 
-	def set_TicketId(self,TicketId):
-		self.add_body_params('TicketId', TicketId)
\ No newline at end of file
+	def set_TicketId(self, TicketId):  # String
+		self.add_body_params('TicketId', TicketId)
